{% macro t(key) %}{{ {
  "language": "pt",
  "edit.link.title": "Editar esta página",
  "footer.previous": "Anterior",
  "footer.next": "Próximo",
  "meta.comments": "Comentários",
  "meta.source": "Fonte",
  "search.languages": "",
  "search.placeholder": "Busca",
  "search.result.placeholder": "Digite para iniciar a busca",
  "search.result.none": "Nenhum resultado encontrado",
  "search.result.one": "1 documento encontrado",
  "search.result.other": "# documentos encontrados",
  "source.link.title": "Ir para o repositório",
  "toc.title": "Tabela de Conteúdos"
}[key] }}{% endmacro %}